/************************************************************************************** 
 * Capacitive Touch Sense Materials Test Code
 * Written by Chris Taylor for SparkFun Electronics, 9/19/12
 * 
 * This code was written to test the capacitive sensing properties of three different
 * materials. The project consists of a board with different sizes of copper tape, 
 * conductive ink, and 1/8" sheet metal. The materials are used as the capacitive 
 * element in an RC circuit. The code utilizes the CapacitiveSense library written by 
 * by Paul Badger. The example circuit, library description, and explanation can be 
 * found here:
 *
 *   http://arduino.cc/playground/Main/CapacitiveSensor?from=Main.CapSense
 * 
 * The connections of the individual RC circuits and their respective send/receive
 * pins is as follows:
 *   
 *  Digital Pins 3 & 4 -- Sheet Metal Send & Receive
 *  Digital Pins 5 & 6 -- Medium Ink Strip Send & Receive 
 *  Digital Pins 7 & 8 -- Large Ink Strip Send & Receive
 *  Digital Pins 9 & 10 -- Medium Copper Tape Send & Receive
 *  Digital Pins 11 & 12 -- Large Copper Tape Send & Receive
 * 
 *  Digital Pin 2 -- Led indicator input pin
 * 
 * This code initializes the CapSense pins, and then checks for a threshold level (500)
 * of the arbitrary units returned by the CapacitiveSensor function. It toggles the
 * LED when it detects a change and reports which material was touched to the terminal.
 *
 * This code is released under the beerware license. If this code ever helps you make
 * anything cool, and you happen to meet me, you can buy me a beer. 
 * 
**************************************************************************************/
 
#include <CapacitiveSensor.h>

#define LED 2 

// INITIALIZE CAPSENSE PINS
// CapacitiveSensor(sendpin, recvpin)  
// sendpin should be the pin connected directly to the resistor
CapacitiveSensor   copperLarge = CapacitiveSensor(11,12);   
CapacitiveSensor   copperMedium = CapacitiveSensor(9,10);   
CapacitiveSensor   inkLarge = CapacitiveSensor(7,8);   
CapacitiveSensor   inkMedium = CapacitiveSensor(5,6);   
CapacitiveSensor   steel = CapacitiveSensor(3,4);   

void setup()
{
  // SET UP COMMUNICATIONS AND LED
  Serial.begin(9600);
  pinMode(LED, OUTPUT);
  
  // CALIBRATE CAPACITIVE SENSE PIN TIMING
  // Setting this value to 0xFFFFFFFF turns of re-calibration (see library page)
  copperLarge.set_CS_AutocaL_Millis(0xFFFFFFFF); 
  copperMedium.set_CS_AutocaL_Millis(0xFFFFFFFF); 
  inkLarge.set_CS_AutocaL_Millis(0xFFFFFFFF); 
  inkMedium.set_CS_AutocaL_Millis(0xFFFFFFFF); 
  steel.set_CS_AutocaL_Millis(0xFFFFFFFF); 
  
  // Send helloworld message to make sure we're alive
  Serial.println("Capacitive Touch Sense Test");  

}

void loop()
{
    // SAMPLE SENSOR CAPACITANCE 
    // These functions sample the receive pins of the sensors 30 times. The largest
    // sample is subtracted from the smallest sample and returns the total. This
    // number is in arbitrary units. 
    long total1 =  copperLarge.capacitiveSensor(30);
    long total2 =  copperMedium.capacitiveSensor(30);
    long total3 =  inkLarge.capacitiveSensor(30);
    long total4 =  inkMedium.capacitiveSensor(30);
    long total5 =  steel.capacitiveSensor(30);

    // CHECK THRESHOLD AND REACT
    // If the returned value is greater than a threshold (I chose 500), light the 
    // LED and print which substrate was touched. 
    if(total1 > 500) { Serial.println("Large Copper"); digitalWrite(LED, HIGH); }
    else if(total2 > 500) { Serial.println("Medium Copper"); digitalWrite(LED, HIGH); }
    else if(total3 > 500) { Serial.println("Large Ink"); digitalWrite(LED, HIGH); }
    else if(total4 > 500) { Serial.println("Medium Ink"); digitalWrite(LED, HIGH); }
    else if(total5 > 500) { Serial.println("Steel"); digitalWrite(LED, HIGH); }
    else { digitalWrite(LED, LOW); }
    
    delay(10); // Delay so we don't print TOO fast
}

